import { ECRClient } from "./ECRClient";
import { BatchCheckLayerAvailabilityInput } from "./types/BatchCheckLayerAvailabilityInput";
import { BatchCheckLayerAvailabilityOutput } from "./types/BatchCheckLayerAvailabilityOutput";
import { BatchDeleteImageInput } from "./types/BatchDeleteImageInput";
import { BatchDeleteImageOutput } from "./types/BatchDeleteImageOutput";
import { BatchGetImageInput } from "./types/BatchGetImageInput";
import { BatchGetImageOutput } from "./types/BatchGetImageOutput";
import { CompleteLayerUploadInput } from "./types/CompleteLayerUploadInput";
import { CompleteLayerUploadOutput } from "./types/CompleteLayerUploadOutput";
import { CreateRepositoryInput } from "./types/CreateRepositoryInput";
import { CreateRepositoryOutput } from "./types/CreateRepositoryOutput";
import { DeleteLifecyclePolicyInput } from "./types/DeleteLifecyclePolicyInput";
import { DeleteLifecyclePolicyOutput } from "./types/DeleteLifecyclePolicyOutput";
import { DeleteRepositoryInput } from "./types/DeleteRepositoryInput";
import { DeleteRepositoryOutput } from "./types/DeleteRepositoryOutput";
import { DeleteRepositoryPolicyInput } from "./types/DeleteRepositoryPolicyInput";
import { DeleteRepositoryPolicyOutput } from "./types/DeleteRepositoryPolicyOutput";
import { DescribeImagesInput } from "./types/DescribeImagesInput";
import { DescribeImagesOutput } from "./types/DescribeImagesOutput";
import { DescribeRepositoriesInput } from "./types/DescribeRepositoriesInput";
import { DescribeRepositoriesOutput } from "./types/DescribeRepositoriesOutput";
import { GetAuthorizationTokenInput } from "./types/GetAuthorizationTokenInput";
import { GetAuthorizationTokenOutput } from "./types/GetAuthorizationTokenOutput";
import { GetDownloadUrlForLayerInput } from "./types/GetDownloadUrlForLayerInput";
import { GetDownloadUrlForLayerOutput } from "./types/GetDownloadUrlForLayerOutput";
import { GetLifecyclePolicyInput } from "./types/GetLifecyclePolicyInput";
import { GetLifecyclePolicyOutput } from "./types/GetLifecyclePolicyOutput";
import { GetLifecyclePolicyPreviewInput } from "./types/GetLifecyclePolicyPreviewInput";
import { GetLifecyclePolicyPreviewOutput } from "./types/GetLifecyclePolicyPreviewOutput";
import { GetRepositoryPolicyInput } from "./types/GetRepositoryPolicyInput";
import { GetRepositoryPolicyOutput } from "./types/GetRepositoryPolicyOutput";
import { InitiateLayerUploadInput } from "./types/InitiateLayerUploadInput";
import { InitiateLayerUploadOutput } from "./types/InitiateLayerUploadOutput";
import { ListImagesInput } from "./types/ListImagesInput";
import { ListImagesOutput } from "./types/ListImagesOutput";
import { ListTagsForResourceInput } from "./types/ListTagsForResourceInput";
import { ListTagsForResourceOutput } from "./types/ListTagsForResourceOutput";
import { PutImageInput } from "./types/PutImageInput";
import { PutImageOutput } from "./types/PutImageOutput";
import { PutImageTagMutabilityInput } from "./types/PutImageTagMutabilityInput";
import { PutImageTagMutabilityOutput } from "./types/PutImageTagMutabilityOutput";
import { PutLifecyclePolicyInput } from "./types/PutLifecyclePolicyInput";
import { PutLifecyclePolicyOutput } from "./types/PutLifecyclePolicyOutput";
import { SetRepositoryPolicyInput } from "./types/SetRepositoryPolicyInput";
import { SetRepositoryPolicyOutput } from "./types/SetRepositoryPolicyOutput";
import { StartLifecyclePolicyPreviewInput } from "./types/StartLifecyclePolicyPreviewInput";
import { StartLifecyclePolicyPreviewOutput } from "./types/StartLifecyclePolicyPreviewOutput";
import { TagResourceInput } from "./types/TagResourceInput";
import { TagResourceOutput } from "./types/TagResourceOutput";
import { UntagResourceInput } from "./types/UntagResourceInput";
import { UntagResourceOutput } from "./types/UntagResourceOutput";
import { UploadLayerPartInput } from "./types/UploadLayerPartInput";
import { UploadLayerPartOutput } from "./types/UploadLayerPartOutput";
export declare class ECR extends ECRClient {
    /**
     * <p>Check the availability of multiple image layers in a specified registry and repository.</p> <note> <p>This operation is used by the Amazon ECR proxy, and it is not intended for general use by customers for pulling and pushing images. In most cases, you should use the <code>docker</code> CLI to pull, tag, and push images.</p> </note>
     *
     * This operation may fail with one of the following errors:
     *   - {RepositoryNotFoundException} <p>The specified repository could not be found. Check the spelling of the specified repository and ensure that you are performing operations on the correct registry.</p>
     *   - {InvalidParameterException} <p>The specified parameter is invalid. Review the available parameters for the API request.</p>
     *   - {ServerException} <p>These errors are usually caused by a server-side issue.</p>
     *   - {Error} An error originating from the SDK or customizations rather than the service
     */
    batchCheckLayerAvailability(args: BatchCheckLayerAvailabilityInput): Promise<BatchCheckLayerAvailabilityOutput>;
    batchCheckLayerAvailability(args: BatchCheckLayerAvailabilityInput, cb: (err: any, data?: BatchCheckLayerAvailabilityOutput) => void): void;
    /**
     * <p>Deletes a list of specified images within a specified repository. Images are specified with either <code>imageTag</code> or <code>imageDigest</code>.</p> <p>You can remove a tag from an image by specifying the image's tag in your request. When you remove the last tag from an image, the image is deleted from your repository.</p> <p>You can completely delete an image (and all of its tags) by specifying the image's digest in your request.</p>
     *
     * This operation may fail with one of the following errors:
     *   - {ServerException} <p>These errors are usually caused by a server-side issue.</p>
     *   - {InvalidParameterException} <p>The specified parameter is invalid. Review the available parameters for the API request.</p>
     *   - {RepositoryNotFoundException} <p>The specified repository could not be found. Check the spelling of the specified repository and ensure that you are performing operations on the correct registry.</p>
     *   - {Error} An error originating from the SDK or customizations rather than the service
     */
    batchDeleteImage(args: BatchDeleteImageInput): Promise<BatchDeleteImageOutput>;
    batchDeleteImage(args: BatchDeleteImageInput, cb: (err: any, data?: BatchDeleteImageOutput) => void): void;
    /**
     * <p>Gets detailed information for specified images within a specified repository. Images are specified with either <code>imageTag</code> or <code>imageDigest</code>.</p>
     *
     * This operation may fail with one of the following errors:
     *   - {ServerException} <p>These errors are usually caused by a server-side issue.</p>
     *   - {InvalidParameterException} <p>The specified parameter is invalid. Review the available parameters for the API request.</p>
     *   - {RepositoryNotFoundException} <p>The specified repository could not be found. Check the spelling of the specified repository and ensure that you are performing operations on the correct registry.</p>
     *   - {Error} An error originating from the SDK or customizations rather than the service
     */
    batchGetImage(args: BatchGetImageInput): Promise<BatchGetImageOutput>;
    batchGetImage(args: BatchGetImageInput, cb: (err: any, data?: BatchGetImageOutput) => void): void;
    /**
     * <p>Informs Amazon ECR that the image layer upload has completed for a specified registry, repository name, and upload ID. You can optionally provide a <code>sha256</code> digest of the image layer for data validation purposes.</p> <note> <p>This operation is used by the Amazon ECR proxy, and it is not intended for general use by customers for pulling and pushing images. In most cases, you should use the <code>docker</code> CLI to pull, tag, and push images.</p> </note>
     *
     * This operation may fail with one of the following errors:
     *   - {ServerException} <p>These errors are usually caused by a server-side issue.</p>
     *   - {InvalidParameterException} <p>The specified parameter is invalid. Review the available parameters for the API request.</p>
     *   - {RepositoryNotFoundException} <p>The specified repository could not be found. Check the spelling of the specified repository and ensure that you are performing operations on the correct registry.</p>
     *   - {UploadNotFoundException} <p>The upload could not be found, or the specified upload id is not valid for this repository.</p>
     *   - {InvalidLayerException} <p>The layer digest calculation performed by Amazon ECR upon receipt of the image layer does not match the digest specified.</p>
     *   - {LayerPartTooSmallException} <p>Layer parts must be at least 5 MiB in size.</p>
     *   - {LayerAlreadyExistsException} <p>The image layer already exists in the associated repository.</p>
     *   - {EmptyUploadException} <p>The specified layer upload does not contain any layer parts.</p>
     *   - {Error} An error originating from the SDK or customizations rather than the service
     */
    completeLayerUpload(args: CompleteLayerUploadInput): Promise<CompleteLayerUploadOutput>;
    completeLayerUpload(args: CompleteLayerUploadInput, cb: (err: any, data?: CompleteLayerUploadOutput) => void): void;
    /**
     * <p>Creates an image repository.</p>
     *
     * This operation may fail with one of the following errors:
     *   - {ServerException} <p>These errors are usually caused by a server-side issue.</p>
     *   - {InvalidParameterException} <p>The specified parameter is invalid. Review the available parameters for the API request.</p>
     *   - {InvalidTagParameterException} <p>An invalid parameter has been specified. Tag keys can have a maximum character length of 128 characters, and tag values can have a maximum length of 256 characters.</p>
     *   - {TooManyTagsException} <p>The list of tags on the repository is over the limit. The maximum number of tags that can be applied to a repository is 50.</p>
     *   - {RepositoryAlreadyExistsException} <p>The specified repository already exists in the specified registry.</p>
     *   - {LimitExceededException} <p>The operation did not succeed because it would have exceeded a service limit for your account. For more information, see <a href="https://docs.aws.amazon.com/AmazonECR/latest/userguide/service_limits.html">Amazon ECR Default Service Limits</a> in the Amazon Elastic Container Registry User Guide.</p>
     *   - {Error} An error originating from the SDK or customizations rather than the service
     */
    createRepository(args: CreateRepositoryInput): Promise<CreateRepositoryOutput>;
    createRepository(args: CreateRepositoryInput, cb: (err: any, data?: CreateRepositoryOutput) => void): void;
    /**
     * <p>Deletes the specified lifecycle policy.</p>
     *
     * This operation may fail with one of the following errors:
     *   - {ServerException} <p>These errors are usually caused by a server-side issue.</p>
     *   - {InvalidParameterException} <p>The specified parameter is invalid. Review the available parameters for the API request.</p>
     *   - {RepositoryNotFoundException} <p>The specified repository could not be found. Check the spelling of the specified repository and ensure that you are performing operations on the correct registry.</p>
     *   - {LifecyclePolicyNotFoundException} <p>The lifecycle policy could not be found, and no policy is set to the repository.</p>
     *   - {Error} An error originating from the SDK or customizations rather than the service
     */
    deleteLifecyclePolicy(args: DeleteLifecyclePolicyInput): Promise<DeleteLifecyclePolicyOutput>;
    deleteLifecyclePolicy(args: DeleteLifecyclePolicyInput, cb: (err: any, data?: DeleteLifecyclePolicyOutput) => void): void;
    /**
     * <p>Deletes an existing image repository. If a repository contains images, you must use the <code>force</code> option to delete it.</p>
     *
     * This operation may fail with one of the following errors:
     *   - {ServerException} <p>These errors are usually caused by a server-side issue.</p>
     *   - {InvalidParameterException} <p>The specified parameter is invalid. Review the available parameters for the API request.</p>
     *   - {RepositoryNotFoundException} <p>The specified repository could not be found. Check the spelling of the specified repository and ensure that you are performing operations on the correct registry.</p>
     *   - {RepositoryNotEmptyException} <p>The specified repository contains images. To delete a repository that contains images, you must force the deletion with the <code>force</code> parameter.</p>
     *   - {Error} An error originating from the SDK or customizations rather than the service
     */
    deleteRepository(args: DeleteRepositoryInput): Promise<DeleteRepositoryOutput>;
    deleteRepository(args: DeleteRepositoryInput, cb: (err: any, data?: DeleteRepositoryOutput) => void): void;
    /**
     * <p>Deletes the repository policy from a specified repository.</p>
     *
     * This operation may fail with one of the following errors:
     *   - {ServerException} <p>These errors are usually caused by a server-side issue.</p>
     *   - {InvalidParameterException} <p>The specified parameter is invalid. Review the available parameters for the API request.</p>
     *   - {RepositoryNotFoundException} <p>The specified repository could not be found. Check the spelling of the specified repository and ensure that you are performing operations on the correct registry.</p>
     *   - {RepositoryPolicyNotFoundException} <p>The specified repository and registry combination does not have an associated repository policy.</p>
     *   - {Error} An error originating from the SDK or customizations rather than the service
     */
    deleteRepositoryPolicy(args: DeleteRepositoryPolicyInput): Promise<DeleteRepositoryPolicyOutput>;
    deleteRepositoryPolicy(args: DeleteRepositoryPolicyInput, cb: (err: any, data?: DeleteRepositoryPolicyOutput) => void): void;
    /**
     * <p>Returns metadata about the images in a repository, including image size, image tags, and creation date.</p> <note> <p>Beginning with Docker version 1.9, the Docker client compresses image layers before pushing them to a V2 Docker registry. The output of the <code>docker images</code> command shows the uncompressed image size, so it may return a larger image size than the image sizes returned by <a>DescribeImages</a>.</p> </note>
     *
     * This operation may fail with one of the following errors:
     *   - {ServerException} <p>These errors are usually caused by a server-side issue.</p>
     *   - {InvalidParameterException} <p>The specified parameter is invalid. Review the available parameters for the API request.</p>
     *   - {RepositoryNotFoundException} <p>The specified repository could not be found. Check the spelling of the specified repository and ensure that you are performing operations on the correct registry.</p>
     *   - {ImageNotFoundException} <p>The image requested does not exist in the specified repository.</p>
     *   - {Error} An error originating from the SDK or customizations rather than the service
     */
    describeImages(args: DescribeImagesInput): Promise<DescribeImagesOutput>;
    describeImages(args: DescribeImagesInput, cb: (err: any, data?: DescribeImagesOutput) => void): void;
    /**
     * <p>Describes image repositories in a registry.</p>
     *
     * This operation may fail with one of the following errors:
     *   - {ServerException} <p>These errors are usually caused by a server-side issue.</p>
     *   - {InvalidParameterException} <p>The specified parameter is invalid. Review the available parameters for the API request.</p>
     *   - {RepositoryNotFoundException} <p>The specified repository could not be found. Check the spelling of the specified repository and ensure that you are performing operations on the correct registry.</p>
     *   - {Error} An error originating from the SDK or customizations rather than the service
     */
    describeRepositories(args: DescribeRepositoriesInput): Promise<DescribeRepositoriesOutput>;
    describeRepositories(args: DescribeRepositoriesInput, cb: (err: any, data?: DescribeRepositoriesOutput) => void): void;
    /**
     * <p>Retrieves a token that is valid for a specified registry for 12 hours. This command allows you to use the <code>docker</code> CLI to push and pull images with Amazon ECR. If you do not specify a registry, the default registry is assumed.</p> <p>The <code>authorizationToken</code> returned for each registry specified is a base64 encoded string that can be decoded and used in a <code>docker login</code> command to authenticate to a registry. The AWS CLI offers an <code>aws ecr get-login</code> command that simplifies the login process.</p>
     *
     * This operation may fail with one of the following errors:
     *   - {ServerException} <p>These errors are usually caused by a server-side issue.</p>
     *   - {InvalidParameterException} <p>The specified parameter is invalid. Review the available parameters for the API request.</p>
     *   - {Error} An error originating from the SDK or customizations rather than the service
     */
    getAuthorizationToken(args: GetAuthorizationTokenInput): Promise<GetAuthorizationTokenOutput>;
    getAuthorizationToken(args: GetAuthorizationTokenInput, cb: (err: any, data?: GetAuthorizationTokenOutput) => void): void;
    /**
     * <p>Retrieves the pre-signed Amazon S3 download URL corresponding to an image layer. You can only get URLs for image layers that are referenced in an image.</p> <note> <p>This operation is used by the Amazon ECR proxy, and it is not intended for general use by customers for pulling and pushing images. In most cases, you should use the <code>docker</code> CLI to pull, tag, and push images.</p> </note>
     *
     * This operation may fail with one of the following errors:
     *   - {ServerException} <p>These errors are usually caused by a server-side issue.</p>
     *   - {InvalidParameterException} <p>The specified parameter is invalid. Review the available parameters for the API request.</p>
     *   - {LayersNotFoundException} <p>The specified layers could not be found, or the specified layer is not valid for this repository.</p>
     *   - {LayerInaccessibleException} <p>The specified layer is not available because it is not associated with an image. Unassociated image layers may be cleaned up at any time.</p>
     *   - {RepositoryNotFoundException} <p>The specified repository could not be found. Check the spelling of the specified repository and ensure that you are performing operations on the correct registry.</p>
     *   - {Error} An error originating from the SDK or customizations rather than the service
     */
    getDownloadUrlForLayer(args: GetDownloadUrlForLayerInput): Promise<GetDownloadUrlForLayerOutput>;
    getDownloadUrlForLayer(args: GetDownloadUrlForLayerInput, cb: (err: any, data?: GetDownloadUrlForLayerOutput) => void): void;
    /**
     * <p>Retrieves the specified lifecycle policy.</p>
     *
     * This operation may fail with one of the following errors:
     *   - {ServerException} <p>These errors are usually caused by a server-side issue.</p>
     *   - {InvalidParameterException} <p>The specified parameter is invalid. Review the available parameters for the API request.</p>
     *   - {RepositoryNotFoundException} <p>The specified repository could not be found. Check the spelling of the specified repository and ensure that you are performing operations on the correct registry.</p>
     *   - {LifecyclePolicyNotFoundException} <p>The lifecycle policy could not be found, and no policy is set to the repository.</p>
     *   - {Error} An error originating from the SDK or customizations rather than the service
     */
    getLifecyclePolicy(args: GetLifecyclePolicyInput): Promise<GetLifecyclePolicyOutput>;
    getLifecyclePolicy(args: GetLifecyclePolicyInput, cb: (err: any, data?: GetLifecyclePolicyOutput) => void): void;
    /**
     * <p>Retrieves the results of the specified lifecycle policy preview request.</p>
     *
     * This operation may fail with one of the following errors:
     *   - {ServerException} <p>These errors are usually caused by a server-side issue.</p>
     *   - {InvalidParameterException} <p>The specified parameter is invalid. Review the available parameters for the API request.</p>
     *   - {RepositoryNotFoundException} <p>The specified repository could not be found. Check the spelling of the specified repository and ensure that you are performing operations on the correct registry.</p>
     *   - {LifecyclePolicyPreviewNotFoundException} <p>There is no dry run for this repository.</p>
     *   - {Error} An error originating from the SDK or customizations rather than the service
     */
    getLifecyclePolicyPreview(args: GetLifecyclePolicyPreviewInput): Promise<GetLifecyclePolicyPreviewOutput>;
    getLifecyclePolicyPreview(args: GetLifecyclePolicyPreviewInput, cb: (err: any, data?: GetLifecyclePolicyPreviewOutput) => void): void;
    /**
     * <p>Retrieves the repository policy for a specified repository.</p>
     *
     * This operation may fail with one of the following errors:
     *   - {ServerException} <p>These errors are usually caused by a server-side issue.</p>
     *   - {InvalidParameterException} <p>The specified parameter is invalid. Review the available parameters for the API request.</p>
     *   - {RepositoryNotFoundException} <p>The specified repository could not be found. Check the spelling of the specified repository and ensure that you are performing operations on the correct registry.</p>
     *   - {RepositoryPolicyNotFoundException} <p>The specified repository and registry combination does not have an associated repository policy.</p>
     *   - {Error} An error originating from the SDK or customizations rather than the service
     */
    getRepositoryPolicy(args: GetRepositoryPolicyInput): Promise<GetRepositoryPolicyOutput>;
    getRepositoryPolicy(args: GetRepositoryPolicyInput, cb: (err: any, data?: GetRepositoryPolicyOutput) => void): void;
    /**
     * <p>Notify Amazon ECR that you intend to upload an image layer.</p> <note> <p>This operation is used by the Amazon ECR proxy, and it is not intended for general use by customers for pulling and pushing images. In most cases, you should use the <code>docker</code> CLI to pull, tag, and push images.</p> </note>
     *
     * This operation may fail with one of the following errors:
     *   - {ServerException} <p>These errors are usually caused by a server-side issue.</p>
     *   - {InvalidParameterException} <p>The specified parameter is invalid. Review the available parameters for the API request.</p>
     *   - {RepositoryNotFoundException} <p>The specified repository could not be found. Check the spelling of the specified repository and ensure that you are performing operations on the correct registry.</p>
     *   - {Error} An error originating from the SDK or customizations rather than the service
     */
    initiateLayerUpload(args: InitiateLayerUploadInput): Promise<InitiateLayerUploadOutput>;
    initiateLayerUpload(args: InitiateLayerUploadInput, cb: (err: any, data?: InitiateLayerUploadOutput) => void): void;
    /**
     * <p>Lists all the image IDs for a given repository.</p> <p>You can filter images based on whether or not they are tagged by setting the <code>tagStatus</code> parameter to <code>TAGGED</code> or <code>UNTAGGED</code>. For example, you can filter your results to return only <code>UNTAGGED</code> images and then pipe that result to a <a>BatchDeleteImage</a> operation to delete them. Or, you can filter your results to return only <code>TAGGED</code> images to list all of the tags in your repository.</p>
     *
     * This operation may fail with one of the following errors:
     *   - {ServerException} <p>These errors are usually caused by a server-side issue.</p>
     *   - {InvalidParameterException} <p>The specified parameter is invalid. Review the available parameters for the API request.</p>
     *   - {RepositoryNotFoundException} <p>The specified repository could not be found. Check the spelling of the specified repository and ensure that you are performing operations on the correct registry.</p>
     *   - {Error} An error originating from the SDK or customizations rather than the service
     */
    listImages(args: ListImagesInput): Promise<ListImagesOutput>;
    listImages(args: ListImagesInput, cb: (err: any, data?: ListImagesOutput) => void): void;
    /**
     * <p>List the tags for an Amazon ECR resource.</p>
     *
     * This operation may fail with one of the following errors:
     *   - {InvalidParameterException} <p>The specified parameter is invalid. Review the available parameters for the API request.</p>
     *   - {RepositoryNotFoundException} <p>The specified repository could not be found. Check the spelling of the specified repository and ensure that you are performing operations on the correct registry.</p>
     *   - {ServerException} <p>These errors are usually caused by a server-side issue.</p>
     *   - {Error} An error originating from the SDK or customizations rather than the service
     */
    listTagsForResource(args: ListTagsForResourceInput): Promise<ListTagsForResourceOutput>;
    listTagsForResource(args: ListTagsForResourceInput, cb: (err: any, data?: ListTagsForResourceOutput) => void): void;
    /**
     * <p>Creates or updates the image manifest and tags associated with an image.</p> <note> <p>This operation is used by the Amazon ECR proxy, and it is not intended for general use by customers for pulling and pushing images. In most cases, you should use the <code>docker</code> CLI to pull, tag, and push images.</p> </note>
     *
     * This operation may fail with one of the following errors:
     *   - {ServerException} <p>These errors are usually caused by a server-side issue.</p>
     *   - {InvalidParameterException} <p>The specified parameter is invalid. Review the available parameters for the API request.</p>
     *   - {RepositoryNotFoundException} <p>The specified repository could not be found. Check the spelling of the specified repository and ensure that you are performing operations on the correct registry.</p>
     *   - {ImageAlreadyExistsException} <p>The specified image has already been pushed, and there were no changes to the manifest or image tag after the last push.</p>
     *   - {LayersNotFoundException} <p>The specified layers could not be found, or the specified layer is not valid for this repository.</p>
     *   - {LimitExceededException} <p>The operation did not succeed because it would have exceeded a service limit for your account. For more information, see <a href="https://docs.aws.amazon.com/AmazonECR/latest/userguide/service_limits.html">Amazon ECR Default Service Limits</a> in the Amazon Elastic Container Registry User Guide.</p>
     *   - {ImageTagAlreadyExistsException} <p>The specified image is tagged with a tag that already exists. The repository is configured for tag immutability.</p>
     *   - {Error} An error originating from the SDK or customizations rather than the service
     */
    putImage(args: PutImageInput): Promise<PutImageOutput>;
    putImage(args: PutImageInput, cb: (err: any, data?: PutImageOutput) => void): void;
    /**
     * <p>Updates the image tag mutability settings for a repository.</p>
     *
     * This operation may fail with one of the following errors:
     *   - {ServerException} <p>These errors are usually caused by a server-side issue.</p>
     *   - {InvalidParameterException} <p>The specified parameter is invalid. Review the available parameters for the API request.</p>
     *   - {RepositoryNotFoundException} <p>The specified repository could not be found. Check the spelling of the specified repository and ensure that you are performing operations on the correct registry.</p>
     *   - {Error} An error originating from the SDK or customizations rather than the service
     */
    putImageTagMutability(args: PutImageTagMutabilityInput): Promise<PutImageTagMutabilityOutput>;
    putImageTagMutability(args: PutImageTagMutabilityInput, cb: (err: any, data?: PutImageTagMutabilityOutput) => void): void;
    /**
     * <p>Creates or updates a lifecycle policy. For information about lifecycle policy syntax, see <a href="https://docs.aws.amazon.com/AmazonECR/latest/userguide/LifecyclePolicies.html">Lifecycle Policy Template</a>.</p>
     *
     * This operation may fail with one of the following errors:
     *   - {ServerException} <p>These errors are usually caused by a server-side issue.</p>
     *   - {InvalidParameterException} <p>The specified parameter is invalid. Review the available parameters for the API request.</p>
     *   - {RepositoryNotFoundException} <p>The specified repository could not be found. Check the spelling of the specified repository and ensure that you are performing operations on the correct registry.</p>
     *   - {Error} An error originating from the SDK or customizations rather than the service
     */
    putLifecyclePolicy(args: PutLifecyclePolicyInput): Promise<PutLifecyclePolicyOutput>;
    putLifecyclePolicy(args: PutLifecyclePolicyInput, cb: (err: any, data?: PutLifecyclePolicyOutput) => void): void;
    /**
     * <p>Applies a repository policy on a specified repository to control access permissions. For more information, see <a href="https://docs.aws.amazon.com/AmazonECR/latest/userguide/RepositoryPolicies.html">Amazon ECR Repository Policies</a> in the <i>Amazon Elastic Container Registry User Guide</i>.</p>
     *
     * This operation may fail with one of the following errors:
     *   - {ServerException} <p>These errors are usually caused by a server-side issue.</p>
     *   - {InvalidParameterException} <p>The specified parameter is invalid. Review the available parameters for the API request.</p>
     *   - {RepositoryNotFoundException} <p>The specified repository could not be found. Check the spelling of the specified repository and ensure that you are performing operations on the correct registry.</p>
     *   - {Error} An error originating from the SDK or customizations rather than the service
     */
    setRepositoryPolicy(args: SetRepositoryPolicyInput): Promise<SetRepositoryPolicyOutput>;
    setRepositoryPolicy(args: SetRepositoryPolicyInput, cb: (err: any, data?: SetRepositoryPolicyOutput) => void): void;
    /**
     * <p>Starts a preview of the specified lifecycle policy. This allows you to see the results before creating the lifecycle policy.</p>
     *
     * This operation may fail with one of the following errors:
     *   - {ServerException} <p>These errors are usually caused by a server-side issue.</p>
     *   - {InvalidParameterException} <p>The specified parameter is invalid. Review the available parameters for the API request.</p>
     *   - {RepositoryNotFoundException} <p>The specified repository could not be found. Check the spelling of the specified repository and ensure that you are performing operations on the correct registry.</p>
     *   - {LifecyclePolicyNotFoundException} <p>The lifecycle policy could not be found, and no policy is set to the repository.</p>
     *   - {LifecyclePolicyPreviewInProgressException} <p>The previous lifecycle policy preview request has not completed. Please try again later.</p>
     *   - {Error} An error originating from the SDK or customizations rather than the service
     */
    startLifecyclePolicyPreview(args: StartLifecyclePolicyPreviewInput): Promise<StartLifecyclePolicyPreviewOutput>;
    startLifecyclePolicyPreview(args: StartLifecyclePolicyPreviewInput, cb: (err: any, data?: StartLifecyclePolicyPreviewOutput) => void): void;
    /**
     * <p>Adds specified tags to a resource with the specified ARN. Existing tags on a resource are not changed if they are not specified in the request parameters.</p>
     *
     * This operation may fail with one of the following errors:
     *   - {InvalidParameterException} <p>The specified parameter is invalid. Review the available parameters for the API request.</p>
     *   - {InvalidTagParameterException} <p>An invalid parameter has been specified. Tag keys can have a maximum character length of 128 characters, and tag values can have a maximum length of 256 characters.</p>
     *   - {TooManyTagsException} <p>The list of tags on the repository is over the limit. The maximum number of tags that can be applied to a repository is 50.</p>
     *   - {RepositoryNotFoundException} <p>The specified repository could not be found. Check the spelling of the specified repository and ensure that you are performing operations on the correct registry.</p>
     *   - {ServerException} <p>These errors are usually caused by a server-side issue.</p>
     *   - {Error} An error originating from the SDK or customizations rather than the service
     */
    tagResource(args: TagResourceInput): Promise<TagResourceOutput>;
    tagResource(args: TagResourceInput, cb: (err: any, data?: TagResourceOutput) => void): void;
    /**
     * <p>Deletes specified tags from a resource.</p>
     *
     * This operation may fail with one of the following errors:
     *   - {InvalidParameterException} <p>The specified parameter is invalid. Review the available parameters for the API request.</p>
     *   - {InvalidTagParameterException} <p>An invalid parameter has been specified. Tag keys can have a maximum character length of 128 characters, and tag values can have a maximum length of 256 characters.</p>
     *   - {TooManyTagsException} <p>The list of tags on the repository is over the limit. The maximum number of tags that can be applied to a repository is 50.</p>
     *   - {RepositoryNotFoundException} <p>The specified repository could not be found. Check the spelling of the specified repository and ensure that you are performing operations on the correct registry.</p>
     *   - {ServerException} <p>These errors are usually caused by a server-side issue.</p>
     *   - {Error} An error originating from the SDK or customizations rather than the service
     */
    untagResource(args: UntagResourceInput): Promise<UntagResourceOutput>;
    untagResource(args: UntagResourceInput, cb: (err: any, data?: UntagResourceOutput) => void): void;
    /**
     * <p>Uploads an image layer part to Amazon ECR.</p> <note> <p>This operation is used by the Amazon ECR proxy, and it is not intended for general use by customers for pulling and pushing images. In most cases, you should use the <code>docker</code> CLI to pull, tag, and push images.</p> </note>
     *
     * This operation may fail with one of the following errors:
     *   - {ServerException} <p>These errors are usually caused by a server-side issue.</p>
     *   - {InvalidParameterException} <p>The specified parameter is invalid. Review the available parameters for the API request.</p>
     *   - {InvalidLayerPartException} <p>The layer part size is not valid, or the first byte specified is not consecutive to the last byte of a previous layer part upload.</p>
     *   - {RepositoryNotFoundException} <p>The specified repository could not be found. Check the spelling of the specified repository and ensure that you are performing operations on the correct registry.</p>
     *   - {UploadNotFoundException} <p>The upload could not be found, or the specified upload id is not valid for this repository.</p>
     *   - {LimitExceededException} <p>The operation did not succeed because it would have exceeded a service limit for your account. For more information, see <a href="https://docs.aws.amazon.com/AmazonECR/latest/userguide/service_limits.html">Amazon ECR Default Service Limits</a> in the Amazon Elastic Container Registry User Guide.</p>
     *   - {Error} An error originating from the SDK or customizations rather than the service
     */
    uploadLayerPart(args: UploadLayerPartInput): Promise<UploadLayerPartOutput>;
    uploadLayerPart(args: UploadLayerPartInput, cb: (err: any, data?: UploadLayerPartOutput) => void): void;
}
